# QBall
QBall is a high-level interpreted language written in Python. It is object oriented and has an easy to learn and use syntax. The following is an example of outputting "Hello, world!" into the console
```
out "Hello, world!";
```
It also has any easy function decleration system
```
$ This is a single line comment
((This is a
multiline comment))
$ This declares a function outarg that takes an argument a
_outarg a;
  out a;
end
outarg "Hello, world!";
```
# Docs
Everything you need to know is in documentation.txt
# Contribute
Go here to contribute: https://repl.it/@qballlang/QBall
Changes are commited 8:00 PM EST every day I can
# Trello board
The official Trello board: https://trello.com/b/cJM6HsR3/qball
